==> laptop-mode-tools_1.71.orig.tar.gz: laptop-mode-tools-1.71/README.md <==
Laptop Mode Tools README
------------------------

Author:  Bart Samwel ([bart@samwel.tk](mailto:bart@samwel.tk), <http://www.samwel.tk/bart/>)  
Maintainer: Ritesh Raj Sarraf ([rrs@researchut.com](mailto:rrs@researchut.com), <http://www.researchut.com>)


Developers
----------

All upstream development is done in the lmt-upstream branch.  
Please base your changes against the lmt-upstream branch


Installation
------------

To install, run `./install.sh`. That's all there's to it.  
This will install laptop mode, which will be enabled automatically
when your laptop works on batteries.

Debian users, please install the Debian package that can
be found on the home page and in the unstable repository!


Notes
-----

* To configure the laptop mode scripts, edit `/etc/laptop-mode/laptop-mode.conf`.

* The laptop mode FAQ can be found at <https://github.com/rickysarraf/laptop-mode-tools/wiki/FAQ>

* The revision history is included in the `Documentation` directory.

* The original laptop mode documentation that was distributed with the Linux
  kernel is included in this package as `Documentation/laptop-mode.txt`. It
  contains some documentation on the internals of laptop mode, and some tips
  and tricks. Note that some of the tips are outdated and superseded by FAQ
  questions.

GUI Configuration Tool
----------------------
![lmt-config-gui](https://github.com/rickysarraf/__pr0n/raw/master/LMT%20GUI.png)

References
----------

The laptop mode tools website: <http://rickysarraf.github.io/laptop-mode-tools/>

==> laptop-mode-tools_1.73.1.orig.tar.gz: laptop-mode-tools-1.73.1/README.md <==
Laptop Mode Tools README
------------------------

Author:  Bart Samwel ([bart@samwel.tk](mailto:bart@samwel.tk), <http://www.samwel.tk/bart/>)  
Maintainer: Ritesh Raj Sarraf ([rrs@researchut.com](mailto:rrs@researchut.com), <http://www.researchut.com>)


Developers
----------

All upstream development is done in the lmt-upstream branch.  
Please base your changes against the lmt-upstream branch


Installation
------------

To install, run `./install.sh`. That's all there's to it.  
This will install laptop mode, which will be enabled automatically
when your laptop works on batteries.

Debian users, please install the Debian package that can
be found in the Debian Package repository at <https://packages.debian.org/search?keywords=laptop-mode-tools>


Notes
-----

* To configure the laptop mode scripts, edit `/etc/laptop-mode/laptop-mode.conf`.

* The laptop mode FAQ can be found at <https://github.com/rickysarraf/laptop-mode-tools/wiki/FAQ>

* The revision history is included in the `Documentation` directory.

* The original laptop mode documentation that was distributed with the Linux
  kernel is included in this package as `Documentation/laptop-mode.txt`. It
  contains some documentation on the internals of laptop mode, and some tips
  and tricks. Note that some of the tips are outdated and superseded by FAQ
  questions.

GUI Configuration Tool
----------------------
![lmt-config-gui](https://github.com/rickysarraf/__pr0n/raw/master/LMT%20GUI.png)

References
----------

The laptop mode tools website: <https://github.com/rickysarraf/laptop-mode-tools/wiki>
